/*
 * Copyright (C) 2024 Rafał Dzięgiel <rafostar.github@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see
 * <https://www.gnu.org/licenses/>.
 */

#pragma once

#if !defined(__CLAPPER_INSIDE__) && !defined(CLAPPER_COMPILATION)
#error "Only <clapper/clapper.h> can be included directly."
#endif

/**
 * CLAPPER_WITH_ENHANCERS_LOADER:
 *
 * Check if Clapper was compiled with Enhancers Loader functionality.
 *
 * Alternatively, apps before compiling can also check whether `pkgconfig`
 * variable named `functionalities` contains `enhancers-loader` string.
 *
 * Since: 0.8
 */
#define CLAPPER_WITH_ENHANCERS_LOADER (TRUE)
